@@ -16,10 +16,10 @@
 """
 import uuid
 
-import mockito
-import pytest
 from iqm_client import IQMClient, RunResult, RunStatus, Status
+import mockito
 from mockito import mock, when
+import pytest
 from qiskit import QuantumCircuit
 from qiskit.providers import JobStatus
 from qiskit.result import Counts
@@ -29,40 +29,30 @@ from qiskit_iqm import IQMBackend, IQMJob
 
 
 @pytest.fixture()
-def job():
+def job(adonis_architecture):
     client = mock(IQMClient)
+    when(client).get_quantum_architecture().thenReturn(adonis_architecture)
     backend = IQMBackend(client)
     return IQMJob(backend, str(uuid.uuid4()))
 
 
 @pytest.fixture()
 def iqm_result_single_register():
-    return {
-        'c_2_0_0': [[0], [1], [0], [1]],
-        'c_2_0_1': [[1], [1], [1], [0]]
-    }
+    return {'c_2_0_0': [[0], [1], [0], [1]], 'c_2_0_1': [[1], [1], [1], [0]]}
 
 
 @pytest.fixture()
 def iqm_result_two_registers():
-    return {
-        'c_2_0_0': [[1], [0], [1], [0]],
-        'c_2_0_1': [[1], [1], [0], [1]],
-        'd_4_1_2': [[1], [1], [1], [1]]
-    }
+    return {'c_2_0_0': [[1], [0], [1], [0]], 'c_2_0_1': [[1], [1], [0], [1]], 'd_4_1_2': [[1], [1], [1], [1]]}
 
 
 @pytest.fixture()
 def iqm_metadata():
-    return {
-        'shots': 4,
-        'circuits': [{'name': 'circuit_1', 'instructions': []}],
-        'calibration_set_id': 123
-    }
+    return {'shots': 4, 'circuits': [{'name': 'circuit_1', 'instructions': []}], 'calibration_set_id': 123}
 
 
 def test_submit_raises(job):
-    with pytest.raises(NotImplementedError, match='Instead, use IQMBackend.run to submit jobs.'):
+    with pytest.raises(NotImplementedError, match='You should never have to submit jobs by calling this method.'):
         job.submit()
 
 
@@ -124,12 +114,12 @@ def test_result_multiple_circuits(job, iqm_result_two_registers):
     iqm_metadata_multiple_circuits = {
         'shots': 4,
         'circuits': [{'name': 'circuit_1', 'instructions': []}, {'name': 'circuit_2', 'instructions': []}],
-        'calibration_set_id': 234
+        'calibration_set_id': 234,
     }
     client_result = RunResult(
         status=Status.READY,
         measurements=[iqm_result_two_registers, iqm_result_two_registers],
-        metadata=iqm_metadata_multiple_circuits
+        metadata=iqm_metadata_multiple_circuits,
     )
     when(job._client).wait_for_results(uuid.UUID(job.job_id())).thenReturn(client_result)
 
